@@ -684,7 +684,7 @@ pub fn typecheck_expr<Tv: Variable, Cv: Variable>(
             }
             Ok((
                 Expr {
-                    itype: Type::NatRange(0.into(), 1.into()),
+                    itype: Type::NatRange(0_i32.into(), 1_i32.into()),
                     inner: ExprInner::IsType(x, t.clone()),
                 },
                 TypeFacts::empty().with_mapping(x, t),
@@ -839,6 +839,28 @@ pub fn typecheck_expr<Tv: Variable, Cv: Variable>(
                 .with_ctx(ctx))
             }
         }
+        RawExpr::Exp(a, b) => {
+            // TODO infer this from b
+            let k = ConstExpr::Lit(255_u32.into());
+            let a: std::sync::Arc<Expr<Tv, Cv>> = recurse(a)?.0.into();
+            let b = typecheck_const_expr(&state, b)?;
+
+            // Check that a is Nat
+            assert_subtype(ctx, &a.itype, &Type::all_nat())?;
+            /*
+            let template: Type<Void, i32> =
+                Type::NatRange(ConstExpr::Var(0), ConstExpr::Var(1));
+            let a_range = template.unify_cvars(&a_expr.itype).unwrap();
+            */
+
+            Ok((
+                Expr {
+                    itype: a.itype.clone(),
+                    inner: ExprInner::Exp(k, a, b),
+                },
+                TypeFacts::empty(),
+            ))
+        }
         RawExpr::Loop(iterations, body, end) => {
             let iterations = typecheck_const_expr(&state, iterations)?;
             let body = body
@@ -1140,7 +1162,7 @@ pub fn typecheck_expr<Tv: Variable, Cv: Variable>(
                 .map(|arg| {
                     let ctx = arg.ctx();
                     let arg = recurse(arg)?.0;
-                    if !arg.itype.subtype_of(&Type::NatRange(0.into(), 255.into())) {
+                    if !arg.itype.subtype_of(&Type::NatRange(0_i32.into(), 255_i32.into())) {
                         Err(anyhow::anyhow!(
                             "element in bytes must be byte-valued, got {:?} instead",
                             arg.itype
@@ -1387,6 +1409,11 @@ fn monomorphize_inner(
                 recurse(&a).into(),
                 recurse(&b).into(),
             ),
+            ExprInner::Exp(k, a, b) => ExprInner::Exp(
+                k.fill(|c| cvar_scope.get(c).cloned().unwrap()),
+                recurse(&a).into(),
+                b.fill(|c| cvar_scope.get(c).cloned().unwrap()),
+            ),
             ExprInner::Let(s, b, i) => ExprInner::Let(s, recurse(&b).into(), recurse(&i).into()),
             ExprInner::Apply(f, args) => {
                 // we must monomorphize the function too
@@ -1515,7 +1542,7 @@ mod tests {
             "{:#?}",
             typecheck_expr(
                 state,
-                parse_program("1 as Nat", module).unwrap().body.clone()
+                parse_program("1 :: Nat", module).unwrap().body.clone()
             )
             .unwrap()
         );
